@@ -1,8 +1,12 @@
-import wcs_util
-from matplotlib.path import Path
-import numpy as np
+from __future__ import absolute_import
 
-def transform(contours, wcs_in, wcs_out, filled=False):
+import numpy as np
+from matplotlib.path import Path
+
+import aplpy.wcs_util as wcs_util
+
+
+def transform(contours, wcs_in, wcs_out, filled=False, overlap=False):
 
     system_in, equinox_in, units_in = wcs_util.system(wcs_in)
     system_out, equinox_out, units_out = wcs_util.system(wcs_out)
@@ -23,8 +27,13 @@ def transform(contours, wcs_in, wcs_out, filled=False):
 
             xp_out, yp_out = wcs_util.world2pix(wcs_out, xw, yw)
 
+            if overlap:
+                if np.all(xp_out < 0) or np.all(yp_out < 0) or \
+                   np.all(xp_out > wcs_out.nx) or np.all(yp_out > wcs_out.ny):
+                    continue
+
             if filled:
-                polygons_out.append(Path(np.array(zip(xp_out, yp_out)),codes=polygon.codes))
+                polygons_out.append(Path(np.array(zip(xp_out, yp_out)), codes=polygon.codes))
             else:
                 polygons_out.append(zip(xp_out, yp_out))
 
