@@ -1,4 +1,7 @@
-from decorators import auto_refresh
+from __future__ import absolute_import
+
+from aplpy.decorators import auto_refresh
+
 
 class Frame(object):
 
