@@ -1,15 +1,16 @@
+from __future__ import absolute_import
+
 import warnings
 
 from mpl_toolkits.axes_grid.anchored_artists \
     import AnchoredEllipse, AnchoredSizeBar
 
+import numpy as np
 from matplotlib.patches import FancyArrowPatch
 from matplotlib.font_manager import FontProperties
-import wcs_util
 
-import numpy as np
-
-from decorators import auto_refresh
+import aplpy.wcs_util as wcs_util
+from aplpy.decorators import auto_refresh
 
 corners = {}
 corners['top right'] = 1
@@ -36,7 +37,7 @@ class Compass(object):
         self._ax1.callbacks.connect('ylim_changed', self.update_compass)
 
     @auto_refresh
-    def show_compass(self, color='red', length = 0.1, corner=4, frame=True):
+    def show_compass(self, color='red', length=0.1, corner=4, frame=True):
         '''
         Display a scalebar
 
@@ -74,15 +75,15 @@ class Compass(object):
 
         w = 2 * length
 
-        pos = {1: (1-w, 1-w),
-               2: (w, 1-w),
+        pos = {1: (1 - w, 1 - w),
+               2: (w, 1 - w),
                3: (w, w),
-               4: (1-w, w),
-               5: (1-w, 0.5),
+               4: (1 - w, w),
+               5: (1 - w, 0.5),
                6: (w, 0.5),
-               7: (1-w, 0.5),
+               7: (1 - w, 0.5),
                8: (0.5, w),
-               9: (0.5, 1-w)}
+               9: (0.5, 1 - w)}
 
         self._compass_position = pos[corner]
         self._compass_length = length
@@ -201,7 +202,7 @@ class ScaleBar(object):
         except:
             pass
 
-        if type(corner) == str:
+        if isinstance(corner, basestring):
             corner = corners[corner]
 
         self._scalebar = AnchoredSizeBar(self._ax.transData, length, label, corner, \
@@ -244,7 +245,7 @@ class ScaleBar(object):
     @auto_refresh
     def set_corner(self, corner):
         '''
-        Set where to place the scalebar. Acceptable values are 'left','right',
+        Set where to place the scalebar. Acceptable values are 'left', 'right',
         'top', 'bottom', 'top left', 'top right', 'bottom left' (default), and
         'bottom right'.
         '''
@@ -398,6 +399,7 @@ class ScaleBar(object):
         warnings.warn("scalebar.set_font_style is deprecated - use scalebar.set_font instead", DeprecationWarning)
         self.set_font(style=style)
 
+
 class Beam(object):
 
     def __init__(self, parent):
@@ -438,7 +440,7 @@ class Beam(object):
                 BPA if present) in the anticlockwise direction.
 
             *corner*: [ integer ]
-                The beam location. Acceptable values are 'left','right',
+                The beam location. Acceptable values are 'left', 'right',
                 'top', 'bottom', 'top left', 'top right', 'bottom left'
                 (default), and 'bottom right'.
 
@@ -452,13 +454,13 @@ class Beam(object):
 
         '''
 
-        if type(major) == str:
+        if isinstance(major, basestring):
             major = self._hdu.header[major]
 
-        if type(minor) == str:
+        if isinstance(minor, basestring):
             minor = self._hdu.header[minor]
 
-        if type(angle) == str:
+        if isinstance(angle, basestring):
             angle = self._hdu.header[angle]
 
         degperpix = wcs_util.degperpix(self._wcs)
@@ -479,7 +481,7 @@ class Beam(object):
         except:
             pass
 
-        if type(corner) == str:
+        if isinstance(corner, basestring):
             corner = corners[corner]
 
         self._beam = AnchoredEllipse(self._ax.transData, \
@@ -534,7 +536,7 @@ class Beam(object):
     @auto_refresh
     def set_corner(self, corner):
         '''
-        Set the beam location. Acceptable values are 'left','right', 'top',
+        Set the beam location. Acceptable values are 'left', 'right', 'top',
         'bottom', 'top left', 'top right', 'bottom left' (default), and
         'bottom right'.
         '''
