@@ -10,6 +10,8 @@ import shutil
 import pyfits
 import numpy as np
 
+from aplpy.logger import logger
+
 try:
     import Image
     installed_pil = True
@@ -50,16 +52,16 @@ def _data_stretch(image, vmin=None, vmax=None, pmin=0.25, pmax=99.75, \
         vmin_auto, vmax_auto = auto_v(pmin), auto_v(pmax)
 
     if min_auto:
-        print "vmin = %10.3e (auto)" % vmin_auto
+        logger.info("vmin = %10.3e (auto)" % vmin_auto)
         vmin = vmin_auto
     else:
-        print "vmin = %10.3e" % vmin
+        logger.info("vmin = %10.3e" % vmin)
 
     if max_auto:
-        print "vmax = %10.3e (auto)" % vmax_auto
+        logger.info("vmax = %10.3e (auto)" % vmax_auto)
         vmax = vmax_auto
     else:
-        print "vmax = %10.3e" % vmax
+        logger.info("vmax = %10.3e" % vmax)
 
     image = (image - vmin) / (vmax - vmin)
 
@@ -71,7 +73,7 @@ def _data_stretch(image, vmin=None, vmax=None, pmin=0.25, pmax=99.75, \
     return data.astype(np.uint8)
 
 
-def make_rgb_image(data, output, \
+def make_rgb_image(data, output, indices=(0, 1, 2), \
                    vmin_r=None, vmax_r=None, pmin_r=0.25, pmax_r=99.75, \
                    stretch_r='linear', vmid_r=None, exponent_r=2, \
                    vmin_g=None, vmax_g=None, pmin_g=0.25, pmax_g=99.75, \
@@ -96,6 +98,12 @@ def make_rgb_image(data, output, \
 
     Optional keyword arguments:
 
+        *indices*: [ tuple ]
+            If data is the filename of a FITS cube, these indices are the
+            positions in the third dimension to use for red, green, and
+            blue respectively. The default is to use the first three
+            indices.
+
         *vmin_r*: [ None | float ]
 
         *vmin_g*: [ None | float ]
@@ -168,12 +176,12 @@ def make_rgb_image(data, output, \
     if not installed_pil:
         raise Exception("The Python Imaging Library (PIL) is not installed but is required for this function")
 
-    if type(data) == str:
+    if isinstance(data, basestring):
 
         image = pyfits.getdata(data)
-        image_r = image[0, :, :]
-        image_g = image[1, :, :]
-        image_b = image[2, :, :]
+        image_r = image[indices[0], :, :]
+        image_g = image[indices[1], :, :]
+        image_b = image[indices[2], :, :]
 
         # Read in header
         header = pyfits.getheader(data)
@@ -199,7 +207,7 @@ def make_rgb_image(data, output, \
     else:
         raise Exception("data should either be the filename of a FITS cube or a list/tuple of three images")
 
-    print "Red:"
+    logger.info("Red:")
     image_r = Image.fromarray(_data_stretch(image_r, \
                                             vmin=vmin_r, vmax=vmax_r, \
                                             pmin=pmin_r, pmax=pmax_r, \
@@ -207,7 +215,7 @@ def make_rgb_image(data, output, \
                                             vmid=vmid_r, \
                                             exponent=exponent_r))
 
-    print "\nGreen:"
+    logger.info("\nGreen:")
     image_g = Image.fromarray(_data_stretch(image_g, \
                                             vmin=vmin_g, vmax=vmax_g, \
                                             pmin=pmin_g, pmax=pmax_g, \
@@ -215,7 +223,7 @@ def make_rgb_image(data, output, \
                                             vmid=vmid_g, \
                                             exponent=exponent_g))
 
-    print "\nBlue:"
+    logger.info("\nBlue:")
     image_b = Image.fromarray(_data_stretch(image_b, \
                                             vmin=vmin_b, vmax=vmax_b, \
                                             pmin=pmin_b, pmax=pmax_b, \
